*                         MICRON HSPICE MODEL
*
* Disclaimer: This software code and all associated documentation, comments
*             or other information (collectively "Software") is provided
*             "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*             ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*             INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*             RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*             FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*             SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*             THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*             MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*             RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*             ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*             OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*             EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*             LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*             SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*             OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*             ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*             EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*             Because some jurisdictions prohibit the exclusion or limitation
*             of liability for consequential or incidental damages, the above
*             limitation may not apply to you.
* 
*             Copyright 2013 Micron Technology, Inc. All rights reserved.
*
************** 256Megx4, 128Megx8, 64Megx16 DDR2 SDRAM ***********************
**********************Example HSPICE setup for DM Input***********************
****
***********************************************************
****             ___                                      *
****            /  +|-PAD----\/\/\/--@@@@--------PKG_IN   *
**** RCVR_OUT--{   -|-VREF   R_pkg  L_pkg     |           *
****            \___|-RCVREN                 ===C_pkg     *
****                                          |           *
****                                         GND          *
****                                                      *
***********************************************************
****
**** This netlist is for the x4, x8, x16 1Gb DDR2 SDRAM 
**** The DM input signal is PKG_IN.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics the subcircuit
**** X_pkg_pad has been attached to the PAD node.
****
**** The .LIB statement selects the following simulation corners:
****   LIB        DATARATE       PROCESS  DIE CAP  VDD/VDDQ
****   ---        --------       -------  -------  --------
****   TYP_533    400/533 Mbps   Typical  Typical  1.800V
****   SLOW_533   400/533 Mbps   Weak     Maximum  1.700V
****   FAST_533   400/533 Mbps   Strong   Minimum  1.900V
****
****   TYP_667    667 Mbps       Typical  Typical  1.800V
****   SLOW_667   667 Mbps       Weak     Maximum  1.700V
****   FAST_667   667 Mbps       Strong   Minimum  1.900V
****
****   TYP_800    800 Mbps       Typical  Typical  1.800V
****   SLOW_800   800 Mbps       Weak     Maximum  1.700V
****   FAST_800   800 Mbps       Strong   Minimum  1.900V
****
****   TYP_1066   1066 Mbps      Typical+ Typical  1.800V
****   SLOW_1066  1066 Mbps      Weak+    Maximum  1.700V
****   FAST_1066  1066 Mbps      Strong   Minimum  1.900V
****
**** To run this simulation, the files "u88b_model.cnr" and "u88b_dmbuff.inc"
**** are required to be in the same directory as this netlist.
****
**** Automotive Industrial temperature settings are: Typical 50C, Slow 110C, Fast -40C
**** Automotive temperature settings are: Typical 50C, Slow 120C, Fast -40C
**** Automotive Ultra-high temperature settings are: Typical 50C, Slow 140C, Fast -40C
***********************************************************

.OPTIONS POST
.OPTIONS METHOD=GEAR ACCURATE
.OPTIONS GSHUNT=1E-12
.INC "u88b_dmbuff.inc"

.TRAN 0.005ns '10*per'

*.LIB "u88b_model.cnr" TYP_533
*.LIB "u88b_model.cnr" TYP_667
.LIB "u88b_model.cnr" TYP_800
*.LIB "u88b_model.cnr" TYP_1066

.TITLE Nominal

**** Temperature is for typical case (AIT=50C, AAT=50C, AUT=50C)
.TEMP 50

***********************************************************
**** POWER SUPPLY PARAMETER 
***********************************************************
**** vccr internal regulated power supply

.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V

.PARAM  vccq_typ  = 1.800V
.PARAM  vccq_min  = 1.700V
.PARAM  vccq_max  = 1.900V

.PARAM  vssq      = 0.000V
.PARAM  vss       = 0.000V

**** Match up typ, min, or max voltages for corner sims
.PARAM  vccq      = vccq_typ
.PARAM  vccr      = vccr_typ

***********************************************************
Vvccq   vccq  0  DC = vccq
Vvccr   vccr  0  DC = vccr
Vvssq   vssq  0  DC = vssq
Vvref   vref  0  DC = '0.5*vccq'
Vvss    vss   0  DC = vss
Vvtt    vtt   0  DC = '0.5*vccq'

***********************************************************
**** INPUT SIGNAL  
***********************************************************
**** Input Stimulus Parameters

*.PARAM datarate = 400.00E6
*.PARAM datarate = 533.33E6
*.PARAM datarate = 666.67E6
.PARAM datarate = 800.00E6
*.PARAM datarate = 1066.67E6
.PARAM pulsewidth = '1/datarate - dataslew'
.PARAM per = '2*(1/datarate)'
.PARAM delay = 2ns
.PARAM dataslew = 300ps

**** Vin toggles the DM at the datarate specified above
Vin    PKG_IN  0  LFSR vssq vccq delay dataslew dataslew datarate 1 [5 2]

***********************************************************
**** RECEIVER ENABLE SIGNAL  
***********************************************************
**** Active high for receiver output (vccr)
Ven    RCVR_EN  0  DC = vccr

***********************************************************
**** ODT SETUP
***********************************************************
**** On-Die Termination is controlled like the Extended Mode Register settings
****   EMR Bit 6     EMR Bit 2     Function
****       0             0         Disabled
****       0             1         75 ohm ODT
****       1             0         150 ohm ODT
****       1             1         50 ohm ODT

**** Active high ODT enable, set odt_en to vccr/vss and set the EMR bits 
**** to toggle ODT on/off

VODT_EN   ODT_EN   0 DC = vss
VODT_EMR2 ODT_EMR2 0 DC = vss
VODT_EMR6 ODT_EMR6 0 DC = vss

***********************************************************
**** TOP CELL:  u88b_dmbuff
***********************************************************
xi0 RCVR_OUT PAD ODT_EMR2 ODT_EMR6 ODT_EN RCVR_EN VREF vss vccr vccq vssq u88b_dmbuff

***********************************************************
**** PACKAGE CONNECTION
***********************************************************
**** Refer to the IBIS model for specific package parasitic values.

x_pkg_pad PAD PKG_IN pkg  r=191.1m l=1.560nH c=0.431pF

.SUBCKT pkg pad pkg_out r=0 l=0 c=0
r_pkg pad net1 R='r'
l_pkg net1 pkg_out L='l'
c_pkg pkg_out gnd C='c'
.ENDS pkg

***********************************************************
.ALTER

.TITLE Weak

.PARAM  vccq        = vccq_min
.PARAM  vccr        = vccr_min

**** Temperature is for slow case (AIT=110C, AAT=120C, AUT=140C)
.TEMP 110

*.LIB "u88b_model.cnr" SLOW_533
*.LIB "u88b_model.cnr" SLOW_667
.LIB "u88b_model.cnr" SLOW_800
*.LIB "u88b_model.cnr" SLOW_1066

***********************************************************
.ALTER

.TITLE Strong

.PARAM  vccq        = vccq_max
.PARAM  vccr        = vccr_max

**** Temperature is for fast case (AIT=-40C, AAT=-40C, AUT=-40C)
.TEMP -40

*.LIB "u88b_model.cnr" FAST_533
*.LIB "u88b_model.cnr" FAST_667
.LIB "u88b_model.cnr" FAST_800
*.LIB "u88b_model.cnr" FAST_1066

***********************************************************
.ALTER

.TITLE Disable Receiver

Ven   RCVR_EN   0  DC = vss

***********************************************************
.END
